% Recreate a path of isotonic solutions based on IRP
% NOTE: in order to compute all isotonic solutions along the path, the
% command would be:
% reCreatePathIRP(y,cutInds,1,size(cutInds,1),options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Inputs:  
% y:          n x 1 vector of input observations
% cutInds:    structure of indices that represents the IRP path (returned by function IRP)
% indStart:   index of path which which to start. e.g., if there are 30
%                partitions in the path, indStart=5 means we want to start 
%                returning the path after 5 partitions.
% count:      number of paths to return.  e.g., if there are 30 partitions, 
%                indStart=3, and count=5, we want to return the solutions
%                created by partitions 3,4,5,6,7.
% options:    same options as to IRP(.) function
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Outputs:  
% pathIRP:   n x count matrix where columns are the isotonic solutions
%                along the IRP path
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Modified by Ronny Luss, May 2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [pathIRP] = reCreatePathIRP(y,cutInds,indStart,count,options)

n=length(y);
pathIRP=zeros(n,count); % return matrix of path of isotonic solutions
yfits=IRP_estimator(y,options,1:n); % initial solution is estimator over all observations
% the path must be created up until the point at which we want to start keeping track of the path
for i=2:indStart
   yfits(cutInds{i,1})=IRP_estimator(y(cutInds{i,1}),options,cutInds{i,1}); % estimator or observations below cut i
   yfits(cutInds{i,2})=IRP_estimator(y(cutInds{i,2}),options,cutInds{i,2}); % estimator or observations above cut i
end

% first solution recorded is already in yfits
pathIRP(:,1)=yfits;
j=2;
for i=(indStart+1):(indStart+count-1) % indices of remaining solutions to compute
   pathIRP(:,j)=pathIRP(:,j-1); % jth solution is a modification to the (j-1)th solution
   pathIRP(cutInds{i,1},j)=IRP_estimator(y(cutInds{i,1}),options,cutInds{i,1}); % estimator or observations below cut i
   pathIRP(cutInds{i,2},j)=IRP_estimator(y(cutInds{i,2}),options,cutInds{i,2}); % estimator or observations above cut i
   j=j+1;
end